@@ -6,14 +6,14 @@ from jsonschema import validate
 
 from pydmt.utils.filesystem import mkdir_touch
 
-from pydmt.builders.one_source_one_target import OneSourceOneTarget
+from pydmt.api.one_source_one_target import OneSourceOneTarget
 
 METADATA = "metadata"
 SCHEMA_URL_JSON = "schema_url_json"
 SCHEMA_URL_YAML = "schema_url_yaml"
 
 
-class YamlValidate(OneSourceOneTarget):
+class BuilderYaml(OneSourceOneTarget):
     def build(self):
         with open(self.source) as yaml_stream:
             data = yaml.safe_load(yaml_stream)
